@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::Chip::Adapter );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
 
@@ -115,6 +115,7 @@ that invocation.
  $exp = $adapter->expect_read_gpios( \@gpios )
  $exp = $adapter->expect_tris_gpios( \@gpios )
  $exp = $adapter->expect_write( $bytes )
+ $exp = $adapter->expect_read( $len )
  $exp = $adapter->expect_write_then_read( $bytes, $len )
  $exp = $adapter->expect_readwrite( $bytes_out )
  $exp = $adapter->expect_assert_ss
@@ -138,6 +139,8 @@ my %METHODS = (
                         [qw( GPIO SPI I2C )] ],
    write           => [ undef,
                         [qw( SPI I2C )] ],
+   read            => [ undef,
+                        [qw( I2C )] ],
    write_then_read => [ undef,
                         [qw( I2C )] ],
    readwrite       => [ undef,
